:orphan:

`plasmapy.utils.decorators.deprecation`
=======================================

.. currentmodule:: plasmapy.utils.decorators.deprecation

.. automodapi::  plasmapy.utils.decorators.deprecation
